@@ -1,14 +1,18 @@
 <?php
-
 /**
  * modifyGroup.php
  *
- * 2002 @ Kelvin Ho. abook_group_plugin v0.1
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * script to modify group
- *
+ * @copyright (c) 2002 Kelvin Ho
+ * @copyright (c) 2002-2004 Jon Nelson <quincy at linuxnotes.net>
+ * @copyright (c) 2004-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: modifyGroup.php,v 1.11 2006/09/13 16:36:42 tokul Exp $
+ * @package sm-plugins
+ * @subpackage abook_group
  */
+
+/** @ignore */
 if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
@@ -24,21 +28,26 @@ global $mailbox, $username;
 /*  Start globals */
 
 sqgetGlobalVar('abook', $abook, SQ_POST);
-sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
-sqgetGlobalVar('username', $username, SQ_POST);
-sqgetGlobalVar('color', $color, SQ_POST);
+// We are not in mailbox
+// sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
+//sqgetGlobalVar('username', $username, SQ_POST);
+//sqgetGlobalVar('color', $color, SQ_POST);
 sqgetGlobalVar('myparams', $myparams, SQ_POST);
 sqgetGlobalVar('message', $message, SQ_POST);
-sqgetGlobalVar('groupName', $groupName, SQ_GET);
-sqgetGlobalVar('opt', $opt, SQ_GET);
-sqgetGlobalVar('opt', $opt, SQ_POST);
+sqgetGlobalVar('groupName', $groupName, SQ_FORM);
+//sqgetGlobalVar('groupName', $groupName, SQ_POST);
+sqgetGlobalVar('opt', $opt, SQ_FORM);
+//sqgetGlobalVar('opt', $opt, SQ_POST);
 sqgetGlobalVar('abookGroups', $abookGroups, SQ_POST);
 sqgetGlobalVar('newGroupName', $newGroupName, SQ_POST);
+sqgetGlobalVar('modifyGroups', $modifyGroups, SQ_POST);
+sqgetGlobalVar('groupConfirmed', $groupConfirmed, SQ_POST);
+sqgetGlobalVar('groupBackout', $groupBackout, SQ_POST);
 
 /*  End globals */
 
 /* Initialize addressbook */
-$abook = addressbook_init();
+$abook = addressbook_init(true,true);
 
 $myparams = array();
 $myparams['dsn'] = $addrbook_dsn;
@@ -48,26 +57,60 @@ $myparams['owner'] = $username;
 $abookGroups = new abook_group_database($myparams);
 
 if (!$opt){
-	$opt = "edit";
+    $opt = "edit";
 }
 
+if ($groupConfirmed=='') $groupConfirmed=false;
+
 if ($opt=="delete"){
-	$abookGroups->deleteGroup($groupName);
+    if(!$groupConfirmed) {
+        displayPageHeader($color, 'None');
+
+        bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+        textdomain('abook_group');
+
+        echo '<br>' .
+            html_tag( 'table', '', 'center', '', 'width="95%" border="0"' ) .
+            html_tag( 'tr',
+                html_tag( 'td', '<b>' . _("Delete Group") . '</b>', 'center', $color[0] ) 
+            ) .
+            html_tag( 'tr' ) .
+            html_tag( 'td', '', 'center', $color[4] ) .
+        _("Are you sure you want to delete ") . '<b>' . $groupName . '</b>?' . 
+        '<FORM ACTION="modifyGroup.php" METHOD="POST"><p>'.
+
+        '<INPUT TYPE=HIDDEN NAME="groupName" VALUE="'.$groupName."\">\n" .
+        '<INPUT TYPE=SUBMIT NAME="groupConfirmed" VALUE="'._("Yes")."\">\n".
+        '<INPUT TYPE=SUBMIT NAME="groupBackout" VALUE="'._("No")."\">\n".
+        '</p></FORM><BR></td></tr></table>';
+        bindtextdomain('squirrelmail', SM_PATH . 'locale');
+        textdomain('squirrelmail');
+        exit;
+    }
+}
+if($groupConfirmed) {
+     $abookGroups->deleteGroup($groupName);
+     header("Location: list_abook_group.php");
+}
+elseif($groupBackout) {
+     header("Location: list_abook_group.php");
 }
 elseif ($opt=="editexe"){
-    $abookGroups->modifyGroup($groupName, $newGroupName);
+       $abookGroups->modifyGroup($groupName, $newGroupName);
+       if ($modifyGroups->error){
+           $message = $modifyGroups->error;
+       }
 }
 
-if ($opt!="edit"){
-	if ($abookGroups->error){
-		$message = $abookGroups->error;
-	}
-	else{
-		header("Location: list_abook_group.php");
-	}
+if ($opt!="edit" and empty($mesage)){
+    if ($abookGroups->error){
+        $message = $abookGroups->error;
+    } else{
+        header("Location: list_abook_group.php");
+    }
 }
 
-displayPageHeader($color, $mailbox);
+displayPageHeader($color, 'None');
 ?>
 
 <table width="95%" align=center cellpadding=2 cellspacing=2 border=0>
@@ -100,7 +143,7 @@ displayPageHeader($color, $mailbox);
         <?php echo $groupName ?>
         </b></td>
     </tr>
-	<tr>
+    <tr>
      <?php 
       bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
       textdomain('abook_group');
@@ -111,7 +154,7 @@ displayPageHeader($color, $mailbox);
       <td width="50%">
         <input type="text" name="newGroupName" value="<?php echo $groupName  ?>">
       </td>
-    </tr>		
+    </tr>
 </table>
   <p align="center">
     <input type="hidden" name="opt" value="editexe">
